@@ -24,7 +24,7 @@
 #--------------------------------------------------------------
 
 
-"kconv" <- function (S=35,T=25,P=0,kf='pf')
+"kconv" <- function (S=35,T=25,P=0,kf='x')
 
 {
 	#--------------------------------------------------------------
