@@ -20,7 +20,7 @@
 # NaOH 1N: 0.1 ml therefore adds 0.1 e-3 mol of OH-, increasing TA
 # DIC is constant in a closed system
 "ppH" <-
-function(flag, sys, var1, var2, pCO2a, vol, N, S=35, T=20, P=0, Pt=0, Sit=0, pHscale="T", k1k2='l', kf='pf'){
+function(flag, sys, var1, var2, pCO2a, vol, N, S=35, T=20, P=0, Pt=0, Sit=0, pHscale="T", k1k2='x', kf='x'){
 	if (sys==0) {
 		ci <- carb(flag=flag, var1=var1, var2=var2, S=S ,T=T, P=P, Pt=Pt, Sit=Sit,  pHscale=pHscale, k1k2=k1k2, kf=kf)
 		alkf <- (ci$ALK + vol*N)/(1+abs(vol)) #final alk - dilution is taken into account
